<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'WR_Session') ):

/**
 * WooRechnung Session Component.
 *
 * @version  1.0.0
 * @package  WooRechnung\Common
 * @author   Zweischneider
 */
final class WR_Session
{
    /**
     * The plugin instance via dependency injection.
     *
     * @var WR_Plugin
     */
    private $_plugin;

	/**
	 * Cookie name used for the session.
	 *
	 * @var string
	 */
    private $_cookie_name;

    /**
     * Data of the session.
     * 
     * @var array
     */
    private $_data = array();

    /**
     * Create a new instance of this invoice factory.
     *
     * @param  WR_Plugin $plugin
     * @return void
     */
    public function __construct(WR_Plugin $plugin)
    {
        $this->_plugin = $plugin;
        add_action('init', array($this, 'init'));
    }

    /**
     * Initializes the session.
     *
     * @return void
     */
    public function init()
    {
        $this->_cookie_name = 'wp_woorechnung_session_' . COOKIEHASH;
        if (empty($_COOKIE[$this->_cookie_name])) {
            return;
        }
        $cookie = wp_unslash($_COOKIE[$this->_cookie_name]);
        $this->_data = json_decode(base64_decode($cookie), true);
    }

    /**
     * Updates session cookie data.
     * 
     * @return void
     */
    public function update_cookie()
    {
        if (!headers_sent()) {
            setcookie($this->_cookie_name, base64_encode(json_encode($this->_data)), time() + HOUR_IN_SECONDS, COOKIEPATH ? COOKIEPATH : '/', COOKIE_DOMAIN, is_ssl(), true);
        } else {
            headers_sent($file, $line);
            $this->_plugin->get_logger()->error("Session start failed! Headers already sent by {$file} on line {$line}.");
        }
    }

    /**
     * Set value in session via key.
     *
     * @param string $key
     * @param mixed $value
     * @return void
     */
    public function set($key, $value)
    {
        $this->_data[sanitize_key($key)] = $value;
        $this->update_cookie();
    }

    /**
     * Check if key isset in session.
     *
     * @param string $key
     * @return bool
     */
    public function isset($key)
    {
        return isset($this->_data[sanitize_key($key)]);
    }

    /**
     * Unset value in session via key.
     *
     * @param string $key
     * @return void
     */
    public function unset($key)
    {
        $key = sanitize_key($key);
        if (isset($this->_data[$key])) {
            unset($this->_data[$key]);
            $this->update_cookie();
        }
    }

    /**
     * Get value from session via key or default if not set.
     *
     * @param string $key
     * @param mixed $default
     * @return mixed
     */
    public function get($key, $default = null)
    {
        $key = sanitize_key($key);
        return isset($this->_data[$key]) ? $this->_data[$key] : $default;
    }
}

endif;
