<?php

// Exit if accessed directly
if ( ! defined('ABSPATH') ) {
    exit;
}

if ( ! class_exists( 'WR_Factory_Error' ) ):

/**
 * WooRechnung Factory Error Class
 *
 * @version  1.0.0
 * @package  WooRechnung\Errors
 * @author   Zweischneider
 */
final class WR_Factory_Error extends WR_Abstract_Error
{
    const WRONG_ORDER_ITEM_ERROR = 0;
    const ORDER_ITEM_MISSING_PRODUCT_ERROR = 1;

    /**
     * Create a new instance of this error.
     *
     * @param  string $data
     * @param  int    $code
     * @return void
     */
    public function __construct($data, $code)
    {
        parent::__construct($data, $code);
    }

    /**
     * Render this error to a printable title and message.
     *
     * @return array
     */
    public function render_error()
    {
        switch ($this->getCode())
        {
            case self::WRONG_ORDER_ITEM_ERROR: return $this->error_wrong_order_item();
            case self::ORDER_ITEM_MISSING_PRODUCT_ERROR: return $this->error_order_item_missing_product();
            default: return $this->error_unknown_reasons();
        }
    }

    /**
     * Render an error for an missing product of an order item.
     *
     * @return array
     */
    public function error_order_item_missing_product()
    {
        $title = __('Produkt zur Bestellposition ist nicht vorhanden', 'woorechnung');
        $message = __('Die Bestellung enthält eine Position, zu der das Produkt nicht (mehr) vorhanden ist. Es können keine Rechnungen erstellt werden, die Positionen enthalten, deren Produkt bereits gelöscht wurde.', 'woorechnung');
        return array('title' => $title, 'message' => $message);
    }

    /**
     * Render an error for an wrong order item.
     *
     * @return array
     */
    public function error_wrong_order_item()
    {
        $title = __('Bestellposition ist kein Produkt', 'woorechnung');
        $message = __('Die Bestellung enthält eine Position, die kein Produkt ist. Bitte prüfe die Bestellung und kontaktiere den Support.', 'woorechnung');
        return array('title' => $title, 'message' => $message);
    }

    /**
     * Render an error with an unknown reason.
     *
     * @return array
     */
    public function error_unknown_reasons()
    {
        $title = __('Ursache unklar', 'woorechnung');
        $message = __('Es ist zu einem unbekannten Fehler gekommen. Bitte kontaktiere den Support, wenn das Problem weiterhin besteht.', 'woorechnung');
        return array('title' => $title, 'message' => $message);
    }
}

endif;
